@@ -32,7 +32,7 @@
 #  @author    Jeff Tanner <jefft@tune.com>
 #  @copyright 2014 TUNE, Inc. (http://www.tune.com)
 #  @license   http://opensource.org/licenses/MIT The MIT License (MIT)
-#  @version   $Date: 2014-12-31 17:01:21 $
+#  @version   $Date: 2015-01-03 08:41:07 $
 #  @link      https://developers.mobileapptracking.com/tune-reporting-sdks @endlink
 #
 #  The Actuals report gives you quick insight into the performance of your apps
@@ -82,7 +82,7 @@ class ExampleAdvertiserReportActuals(object):
         # Setup SDK Configuration with TUNE MobileAppTracking API Key.
         dirname = os.path.split(__file__)[0]
         dirname = os.path.dirname(dirname)
-        filepath = os.path.join(dirname, SdkConfig.SDK_CONFIG_FILENAME)
+        filepath = os.path.join(dirname, "config", SdkConfig.SDK_CONFIG_FILENAME)
 
         abspath = os.path.abspath(filepath)
 
@@ -139,6 +139,9 @@ class ExampleAdvertiserReportActuals(object):
             print(" TuneManagementResponse:")
             print(str(response))
 
+            print(" JSON:")
+            print(response.json)
+
             print(" Count:")
             print(str(response.data))
 
@@ -166,6 +169,9 @@ class ExampleAdvertiserReportActuals(object):
             print(" TuneManagementResponse:")
             print(str(response))
 
+            print(" JSON:")
+            print(response.json)
+
             print("")
             print("===========================================================")
             print(" Find Advertiser Report Actuals with Recommended fields.   ")
@@ -190,6 +196,9 @@ class ExampleAdvertiserReportActuals(object):
             print(" TuneManagementResponse:")
             print(str(response))
 
+            print(" JSON:")
+            print(response.json)
+
             print("")
             print("===========================================================")
             print(" Export Advertiser Report Actuals CSV                      ")
@@ -212,6 +221,9 @@ class ExampleAdvertiserReportActuals(object):
             print(" TuneManagementResponse:")
             print(str(response))
 
+            print(" JSON:")
+            print(str(response.json))
+
             job_id = AdvertiserReportActuals.parse_response_report_job_id(response)
 
             print(" CSV Job ID: {}".format(job_id))
@@ -262,6 +274,9 @@ class ExampleAdvertiserReportActuals(object):
             print(" TuneManagementResponse:")
             print(str(response))
 
+            print(" JSON:")
+            print(response.json)
+
             job_id = AdvertiserReportActuals.parse_response_report_job_id(response)
 
             print(" JSON Job ID: {}".format(job_id))
